@@ -21,15 +21,18 @@ class TestBase(unittest.TestCase):
     def createPythonScript(self, id_, title, code):
         """Creare new Python Script object."""
         ps = PythonScript(id_)
-        ps.ZPythonScript_setTitle(title)
+        if title:
+            ps.ZPythonScript_setTitle(title)
         ps.write(code)
         ps._makeFunction()
         return ps
 
-    def addPythonScript(self, id_, title, code):
+    def addPythonScript(self, id_, title, code, container=None):
         """Add new Python Script to Plone Site."""
         ps = self.createPythonScript(id_, title, code)
-        self.ploneSite[id_] = ps
+        if container is None:
+            container = self.ploneSite
+        container[id_] = ps
         return ps
 
     def getScriptManager(self):
